
CHANGELOG
=========

This is the changelog for PieCrust.

The first section deals with the latest changes in the development branch
(``default`` in Mercurial, ``master`` in Git).

The second section deals with changes in the stable branch (``stable`` in
Mercurial, ``git-stable`` in Git), but those changes are also included in the
development branch (the development branch is ahead of the stable branch).


Fresh changes
-------------

*None... this stuff is still being prepared...*

Frozen changes
--------------

*None... this stuff is still being prepared...*

